#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Feb 27 15:43:34 2023

@author: mathis.nenach
"""

from setuptools import setup

setup(
    name='MathisN_Test_Pariel',
    version='0.1',
    packages=["Project_Test"],
    install_requires=[
        
    ],
    include_package_data=True,
    author='Mathis',
    author_email='mathis.nenach@cpe.fr',
    description='Effectue les 4 opérations élémentaires sur 2 complexes',
    classifiers=[
        'Programming Language :: Python :: 3',
    ],
)
